==> opensaml-soap-impl-3.4.4-sources.jar: org/opensaml/soap/wsaddressing/impl/AttributedURIMarshaller.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.soap.wsaddressing.impl;


import net.shibboleth.utilities.java.support.xml.ElementSupport;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.MarshallingException;
import org.opensaml.core.xml.util.XMLObjectSupport;
import org.opensaml.soap.wsaddressing.AttributedURI;
import org.w3c.dom.Element;

/**
 * Abstract marshaller for the element of type {@link AttributedURI}.
 * 
 */
public class AttributedURIMarshaller extends AbstractWSAddressingObjectMarshaller {

    /** {@inheritDoc} */
    protected void marshallElementContent(final XMLObject xmlObject, final Element domElement)
            throws MarshallingException {
        final AttributedURI attributedURI = (AttributedURI) xmlObject;
        ElementSupport.appendTextContent(domElement, attributedURI.getValue());
    }

    /** {@inheritDoc} */
    protected void marshallAttributes(final XMLObject xmlObject, final Element domElement) throws MarshallingException {
        final AttributedURI attributedURI = (AttributedURI) xmlObject;
        XMLObjectSupport.marshallAttributeMap(attributedURI.getUnknownAttributes(), domElement);
    }
}

==> opensaml-soap-impl-4.1.1-sources.jar: org/opensaml/soap/wsaddressing/impl/AttributedURIMarshaller.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.soap.wsaddressing.impl;


import net.shibboleth.utilities.java.support.xml.ElementSupport;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.MarshallingException;
import org.opensaml.core.xml.util.XMLObjectSupport;
import org.opensaml.soap.wsaddressing.AttributedURI;
import org.w3c.dom.Element;

/**
 * Abstract marshaller for the element of type {@link AttributedURI}.
 * 
 */
public class AttributedURIMarshaller extends AbstractWSAddressingObjectMarshaller {

    /** {@inheritDoc} */
    protected void marshallElementContent(final XMLObject xmlObject, final Element domElement)
            throws MarshallingException {
        final AttributedURI attributedURI = (AttributedURI) xmlObject;
        ElementSupport.appendTextContent(domElement, attributedURI.getURI());
    }

    /** {@inheritDoc} */
    protected void marshallAttributes(final XMLObject xmlObject, final Element domElement) throws MarshallingException {
        final AttributedURI attributedURI = (AttributedURI) xmlObject;
        XMLObjectSupport.marshallAttributeMap(attributedURI.getUnknownAttributes(), domElement);
    }
}
